@@ -1783,7 +1783,7 @@ ptp_unpack_EOS_FocusInfoEx (PTPParams* params, unsigned char** data, uint32_t da
 		return NULL;
 	p = str;
 
-	p += sprintf(p,"eosversion=%d,size=%dx%d,size2=%dx%d,points={", version, sizeX, sizeY, size2X, size2Y);
+	p += sprintf(p,"eosversion=%u,size=%ux%u,size2=%ux%u,points={", version, sizeX, sizeY, size2X, size2Y);
 	for (i=0;i<focus_points_in_use;i++) {
 		int16_t x = dtoh16a((*data) + focus_points_in_struct*4 + 20 + 2*i);
 		int16_t y = dtoh16a((*data) + focus_points_in_struct*6 + 20 + 2*i);
@@ -1798,7 +1798,7 @@ ptp_unpack_EOS_FocusInfoEx (PTPParams* params, unsigned char** data, uint32_t da
 	p += sprintf(p,"},select={");
 	for (i=0;i<focus_points_in_use;i++) {
 		if ((1<<(i%8)) & ((*data)[focus_points_in_struct*8+20+i/8]))
-			p+=sprintf(p,"%d,", i);
+			p+=sprintf(p,"%u,", i);
 	}
 
 	p += sprintf(p,"},unknown={");
@@ -2102,12 +2102,12 @@ ptp_unpack_CANON_changes (PTPParams *params, unsigned char* data, int datasize,
 				switch (dpd->DataType) {
 #define XX( TYPE, CONV )\
 					if (sizeof(dpd->FORM.Enum.SupportedValue[j].TYPE)*propxcnt + PTP_ece_Prop_Desc_Data > size) {	\
-						ptp_debug (params, "size %d does not match needed %d", sizeof(dpd->FORM.Enum.SupportedValue[j].TYPE)*propxcnt + PTP_ece_Prop_Desc_Data, size);	\
+						ptp_debug (params, "size %lu does not match needed %u", sizeof(dpd->FORM.Enum.SupportedValue[j].TYPE)*propxcnt + PTP_ece_Prop_Desc_Data, size);	\
 						break;							\
 					}								\
 					for (j=0;j<propxcnt;j++) { 					\
 						dpd->FORM.Enum.SupportedValue[j].TYPE = CONV(xdata); 	\
-						ptp_debug (params, "event %d: suppval[%d] of %x is 0x%x.", i, j, proptype, CONV(xdata)); \
+						ptp_debug (params, "event %u: suppval[%u] of %x is 0x%x.", i, j, proptype, CONV(xdata)); \
 						xdata += 4; /* might only be for propxtype 3 */ \
 					} \
 					break;
@@ -2226,6 +2226,8 @@ ptp_unpack_CANON_changes (PTPParams *params, unsigned char* data, int datasize,
 				case PTP_DPC_CANON_EOS_AFSelectFocusArea:
 				case PTP_DPC_CANON_EOS_ContinousAFMode:
 				case PTP_DPC_CANON_EOS_MirrorUpSetting:
+				case PTP_DPC_CANON_EOS_OLCInfoVersion:
+				case PTP_DPC_CANON_EOS_PowerZoomPosition:
 					dpd->DataType = PTP_DTC_UINT32;
 					break;
 				/* enumeration for AEM is never provided, but is available to set */
@@ -2414,10 +2416,27 @@ ptp_unpack_CANON_changes (PTPParams *params, unsigned char* data, int datasize,
 				break;
 		}
 		/* one more information record handed to us */
+		/* Versions seen: (d199)
+		 * 100D: 	7 (original reference)
+		 * 5d Mark 3:	7
+		 * 650D:	7
+		 * 6D:		7
+		 * M10:		8
+		 * 70D:		8
+		 * 5Dsr:	b
+		 * 200D: 	f
+		 */
 		case PTP_EC_CANON_EOS_OLCInfoChanged: {
 			uint32_t		len, curoff;
 			uint16_t		mask,proptype;
 			PTPDevicePropDesc	*dpd;
+			int			olcver = 0;
+
+			dpd = _lookup_or_allocate_canon_prop(params, PTP_DPC_CANON_EOS_OLCInfoVersion);
+			if (dpd) {
+				ptp_debug (params, "olcinfoversion is %d", dpd->CurrentValue.u32);
+				olcver = dpd->CurrentValue.u32;
+			}
 
 			/* unclear what OLC stands for */
 			ptp_debug (params, "event %d: EOS event OLCInfoChanged (size %d)", i, size);
@@ -2446,35 +2465,58 @@ ptp_unpack_CANON_changes (PTPParams *params, unsigned char* data, int datasize,
 				ce[i].u.info = malloc(strlen("Button 1234567"));
 				sprintf(ce[i].u.info, "Button %d",  dtoh16a(curdata+curoff));
 				i++;
-				curoff += 2;
+				curoff += 2; /* 7, 8 , f */
 			}
 			
 			if (mask & CANON_EOS_OLC_SHUTTERSPEED) {
 				/* 6 bytes: 01 01 98 10 00 60 */
 				/* this seesm to be the shutter speed record */
+				/* EOS 200D seems to have 7 bytes here, sample:
+				 * 7 bytes: 01 03 98 10 00 70 00 
+				 */
 				proptype = PTP_DPC_CANON_EOS_ShutterSpeed;
 				dpd = _lookup_or_allocate_canon_prop(params, proptype);
 				dpd->CurrentValue.u16 = curdata[curoff+5]; /* just use last byte */
 
 				ce[i].type = PTP_CANON_EOS_CHANGES_TYPE_PROPERTY;
 				ce[i].u.propid = proptype;
-				curoff += 6;
+				/* hack to differ between older EOS and EOS 200D newer */
+				switch (olcver) {
+				case 0xf:
+					curoff += 7;	/* f (200D), 8 (M10) */
+					break;
+				case 0x7:
+				case 0x8: /* EOS 70D */
+				case 0xb: /* EOS 5Ds */
+					curoff += 6;	/* 7 , b (5ds) */
+					break;
+				default:
+					curoff += 6;
+					break;
+				}
 				i++;
 			}
 			if (mask & CANON_EOS_OLC_APERTURE) {
 				/* 5 bytes: 01 01 5b 30 30 */
 				/* this seesm to be the aperture record */
+				/* EOS 200D seems to have 6 bytes here?
+				 * 6 bytes: 01 01 50 20 20 00 *
+				 */
 				proptype = PTP_DPC_CANON_EOS_Aperture;
 				dpd = _lookup_or_allocate_canon_prop(params, proptype);
 				dpd->CurrentValue.u16 = curdata[curoff+4]; /* just use last byte */
 
 				ce[i].type = PTP_CANON_EOS_CHANGES_TYPE_PROPERTY;
 				ce[i].u.propid = proptype;
-				curoff += 5;
+				if (olcver >= 0xf) {
+					curoff += 6;	/* f */
+				} else {
+					curoff += 5;	/* 7, 8, b */
+				}
 				i++;
 			}
 			if (mask & CANON_EOS_OLC_ISO) {
-				/* 5 bytes: 01 01 00 78 */
+				/* 4 bytes: 01 01 00 78 */
 				/* this seesm to be the aperture record */
 				proptype = PTP_DPC_CANON_EOS_ISOSpeed;
 				dpd = _lookup_or_allocate_canon_prop(params, proptype);
@@ -2482,7 +2524,7 @@ ptp_unpack_CANON_changes (PTPParams *params, unsigned char* data, int datasize,
 
 				ce[i].type = PTP_CANON_EOS_CHANGES_TYPE_PROPERTY;
 				ce[i].u.propid = proptype;
-				curoff += 4;
+				curoff += 4;	/* 7, 8, b, f*/
 				i++;
 			}
 			if (mask & 0x0010) {
@@ -2642,7 +2684,7 @@ ptp_unpack_CANON_changes (PTPParams *params, unsigned char* data, int datasize,
 		case PTP_EC_CANON_EOS_BulbExposureTime:
 			ce[i].type = PTP_CANON_EOS_CHANGES_TYPE_UNKNOWN;
 			ce[i].u.info = malloc(strlen("BulbExposureTime 123456789012345678"));
-			sprintf (ce[i].u.info, "BulbExposureTime %d",  dtoh32a(curdata+8));
+			sprintf (ce[i].u.info, "BulbExposureTime %u",  dtoh32a(curdata+8));
 			break;
 		case PTP_EC_CANON_EOS_ObjectRemoved:
 			ce[i].type = PTP_CANON_EOS_CHANGES_TYPE_OBJECTREMOVED;
@@ -2651,9 +2693,9 @@ ptp_unpack_CANON_changes (PTPParams *params, unsigned char* data, int datasize,
 		default:
 			switch (type) {
 #define XX(x)		case PTP_EC_CANON_EOS_##x: 								\
-				ptp_debug (params, "event %d: unhandled EOS event "#x" (size %d)", i, size); 	\
+				ptp_debug (params, "event %u: unhandled EOS event "#x" (size %u)", i, size); 	\
 				ce[i].u.info = malloc(strlen("unhandled EOS event "#x" (size 123456789)"));	\
-				sprintf (ce[i].u.info, "unhandled EOS event "#x" (size %d)",  size);		\
+				sprintf (ce[i].u.info, "unhandled EOS event "#x" (size %u)",  size);		\
 				break;
 			XX(RequestGetEvent)
 			XX(RequestGetObjectInfoEx)
